hotstuff

package module
v0.0.0-...-f586533 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 7, 2020 License: MIT Imports: 14 Imported by: 0

README

hotstuff

Test golangci-lint

relab/hotstuff is an implementation of the HotStuff protocol [1]. It uses the Gorums [2] RPC framework for sending messages between replicas.

Running the examples

We have written an example client located in cmd/hotstuffclient and an example server located in cmd/hotstuffserver. These can be compiled by running make. They read a configuration file named hotstuff.toml from the working directory. An example configuration that runs on localhost is included in the root of the project. To generate public and private keys for the servers, run cmd/hotstuffkeygen/hotstuffkeygen -p 'r*' -n 4 --hosts 127.0.0.1 --tls keys. To start four servers, run scripts/run_servers.sh with any desired options. To start the client, run cmd/hotstuffclient/hotstuffclient.

TODO

  • Further benchmarking and testing
  • Improving performance
    • Allow leaders to send command hashes instead of resending whole commands.
  • Allow a replica to "catch up" by fetching missing nodes
  • Add reconfiguration

References

[1] M. Yin, D. Malkhi, M. K. Reiter, G. Golan Gueta, and I. Abraham, “HotStuff: BFT Consensus in the Lens of Blockchain,” Mar 2018.

[2] Tormod Erevik Lea, Leander Jehl, and Hein Meling. Towards New Abstractions for Implementing Quorum-based Systems. In 37th International Conference on Distributed Computing Systems (ICDCS), Jun 2017.

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type HotStuff

type HotStuff struct {
	*consensus.HotStuffCore
	proto.UnimplementedHotstuffServer
	// contains filtered or unexported fields
}

HotStuff is a thing

func New

func New(conf *config.ReplicaConfig, pacemaker Pacemaker, tls bool, connectTimeout, qcTimeout time.Duration) *HotStuff

New creates a new GorumsHotStuff backend object.

func (*HotStuff) Close

func (hs *HotStuff) Close()

Close closes all connections made by the HotStuff instance

func (*HotStuff) Propose

func (hs *HotStuff) Propose()

Propose broadcasts a new proposal to all replicas

func (*HotStuff) Start

func (hs *HotStuff) Start() error

Start starts the server and client

type Pacemaker

type Pacemaker interface {
	GetLeader(view int) config.ReplicaID
}

Pacemaker is a mechanism that provides synchronization

Directories

Path Synopsis
cmd
genSchedule command
hotstuffclient command
hotstuffkeygen command
hotstuffserver command
internal
proto
proto的类型是用于rpc时的传输,它的字段会更精简;而普通数据结构是存在 本地的,它会记录更多的字段。
proto的类型是用于rpc时的传输,它的字段会更精简;而普通数据结构是存在 本地的,它会记录更多的字段。

Jump to